@@ -8,7 +8,6 @@ from zodict import zodict
 from zope.interface import implements
 from zope.location import LocationIterator
 from interfaces import INode
-from deco import accepts, returns
 
 class Node(zodict):
     implements(INode)
@@ -23,9 +22,9 @@ class Node(zodict):
 
     def __setitem__(self, key, val):
         if val.uuid in self._index.keys():
-            raise ValueError(u"Node with uuid already exists")
+            raise ValueError, u"Node with uuid already exists"
         if inspect.isclass(val):
-            raise ValueError(u"It isn't allowed to use classes as values.")
+            raise ValueError, u"It isn't allowed to use classes as values."
         val.__name__ = key
         val.__parent__ = self
         val._index = self._index
@@ -41,16 +40,14 @@ class Node(zodict):
         del self._index[todelete.uuid]
         zodict.__delitem__(self, key)
 
-    @accepts(object, uuid.UUID)
     def set_uuid(self, uuid):
         if uuid in self._index.keys() and self._index[uuid] is not self:
-            raise ValueError(u"Given uuid was already used for another Node")
+            raise ValueError, u"Given uuid was already used for another Node"
         if self._uuid in self._index.keys():
             del self._index[self._uuid]
         self._index[uuid] = self
         self._uuid = uuid
 
-    @returns(uuid.UUID)
     def get_uuid(self):
         return self._uuid
 
@@ -70,6 +67,10 @@ class Node(zodict):
         for parent in LocationIterator(self):
             root = parent
         return root
+    
+    @property
+    def index(self):
+        return self._index
 
     def node(self, uuid):
         return self._index.get(uuid)
@@ -82,9 +83,8 @@ class Node(zodict):
     def insertbefore(self, newnode, refnode):
         self._validateinsertion(newnode, refnode)
         nodekey = newnode.__name__
-        index = self._nodeindex(refnode)
         refkey = refnode.__name__
-        refnode = dict.__getitem__(self, refkey)
+        index = self._nodeindex(refnode)
         prevnode = None
         prevkey = None
         if index > 0:
@@ -103,9 +103,8 @@ class Node(zodict):
     def insertafter(self, newnode, refnode):
         self._validateinsertion(newnode, refnode)
         nodekey = newnode.__name__
-        index = self._nodeindex(refnode)
         refkey = refnode.__name__
-        refnode = dict.__getitem__(self, refkey)
+        index = self._nodeindex(refnode)
         nextnode = None
         nextkey = None
         keys = self.keys()
@@ -125,12 +124,12 @@ class Node(zodict):
     def _validateinsertion(self, newnode, refnode):
         nodekey = newnode.__name__
         if nodekey is None:
-            raise ValueError(u"Given node has no __name__ set.")
+            raise ValueError, u"Given node has no __name__ set."
         if self.node(newnode.uuid) is not None:
-            raise KeyError(u"Given node already contained in tree.")
+            raise KeyError, u"Given node already contained in tree."
         index = self._nodeindex(refnode)
         if index is None:
-            raise ValueError(u"Given reference node not child of self.")
+            raise ValueError, u"Given reference node not child of self."
     
     def _nodeindex(self, node):
         index = 0
